from setuptools import setup

setup(name='jkj_probability_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['jkj_probability_distributions'],
      author = 'Jyothish James',
      author_mail = 'jyothishlp@gmail.com',	
      zip_safe=False)
